@@ -20,14 +20,14 @@
 #ifndef __SUBTRACK_H__
 #define __SUBTRACK_H__
 
-#include "AudioData.h"
+#include "TrackData.h"
 
-class SubTrack : public AudioData {
+class SubTrack : public TrackData {
 public:
   enum Type { PAD, DATA };
 
-  SubTrack(Type, unsigned long start, const AudioData &);
-  SubTrack(Type, const AudioData &);
+  SubTrack(Type, unsigned long start, const TrackData &);
+  SubTrack(Type, const TrackData &);
   SubTrack(const SubTrack &);
   ~SubTrack();
 
@@ -40,8 +40,10 @@ private:
   Type type_;
 
   class SubTrack *next_;
+  class SubTrack *pred_;
 
   friend class Track;
+  friend class TrackReader;
 };
 
 
