@@ -16,18 +16,44 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
+/*
+ * $Log: util.h,v $
+ * Revision 1.4  1999/03/27 19:51:04  mueller
+ * Added 'strdup3CC()'.
+ *
+ * Revision 1.3  1999/01/24 15:59:02  mueller
+ * Moved 'audioDataLength()', 'audioFileType()' and 'waveHeaderLength()'
+ * to class 'AudioData'.
+ *
+ * Revision 1.2  1998/09/06 12:00:26  mueller
+ * Used 'message' function for messages.
+ *
+ */
 
 #ifndef __UTIL_H__
 #define __UTIL_H__
 
+#include <stdio.h>
+
 class Sample;
 
 char *strdupCC(const char *s);
+char *strdup3CC(const char *s1, const char *s2, const char *s3);
+
 long fullRead(int fd, void *buf, long count);
-int audioDataLength(const char *fname, unsigned long *length);
-int audioFileType(const char *filename);
-long waveHeaderLength(const char *filename);
+long fullWrite(int fd, const void *buf, long count);
+long readLong(FILE *fp);
+short readShort(FILE *fp);
+
 void swapSamples(Sample *buf, unsigned long len);
 
+unsigned char int2bcd(int);
+int bcd2int(unsigned char);
+
+const char *stripCwd(const char *fname);
+
+void message(int level, const char *fmt, ...);
+
+
 #endif
 
